==> lifestyle-pimcore-sylius-1.0.1-493bb3.zip: src/Lifestyle/Pimcore/SyliusBundle/Export/Product/Version1/Create/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create;

use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create\Model\Product;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create\Model\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create
 */
class Mapper
{
    /**
     * @param DataCollectorInterface $collector
     * @return Product
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = new Product();
        $product->setCode($collector->getItemValue('id'));
        $product->setMainTaxon($collector->getItemValue('mainTaxon'));
        $product->setChannels($collector->getItemValue('channels'));
        $product->setEnabled(true);

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $translation = new Translation();

            $this->mapTranslationField($translation, $collector, 'name', $locale);
            $this->mapTranslationField($translation, $collector, 'slug', $locale);
            $this->mapTranslationField($translation, $collector, 'description', $locale);
            $this->mapTranslationField($translation, $collector, 'shortDescription', $locale);
            $this->mapTranslationField($translation, $collector, 'metaKeywords', $locale);
            $this->mapTranslationField($translation, $collector, 'metaDescription', $locale);

            $translation->setLocale($locale);
            $product->addTranslation($translation);
        }

        return $product;
    }

    /**
     * @param Translation $translation
     * @param DataCollectorInterface $collector
     * @param string $fieldName
     * @param string $locale
     */
    private function mapTranslationField(Translation $translation, DataCollectorInterface $collector, $fieldName, $locale)
    {
        if ($collector->hasItem($fieldName, $locale)) {
            $method = 'set' . ucfirst(strtolower($fieldName));
            $translation->$method($collector->getItemValue($fieldName, $locale));
        }
    }
}

==> lifestyle-pimcore-sylius-1.0.2-986783.zip: src/Lifestyle/Pimcore/SyliusBundle/Export/Product/Version1/Create/Mapper.php <==
<?php

/**
 * Class Mapper
 *
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * @copyright  2017 Lifestyle Webconsulting GmbH
 * @link       http://www.life-style.de
 */

namespace Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create;

use Lifestyle\Pimcore\ExportBundle\Mapping\DataCollector\DataCollectorInterface;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create\Model\Request\Product;
use Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create\Model\Request\Translation;

/**
 * Class Mapper
 * @package Lifestyle\Pimcore\SyliusBundle\Export\Product\Version1\Create
 */
class Mapper
{
    /**
     * @param DataCollectorInterface $collector
     * @return Product
     */
    public function mapRequestModel(DataCollectorInterface $collector)
    {
        $product = new Product();
        $product->setCode($collector->getItemValue('id'));
        $product->setMainTaxon($collector->getItemValue('mainTaxon'));
        $product->setChannels($collector->getItemValue('channels'));
        $product->setEnabled(true);

        $locales = $collector->getCollectedLocales();
        foreach ($locales as $locale) {
            $translation = new Translation();

            $this->mapTranslationField($translation, $collector, 'name', $locale);
            $this->mapTranslationField($translation, $collector, 'slug', $locale);
            $this->mapTranslationField($translation, $collector, 'description', $locale);
            $this->mapTranslationField($translation, $collector, 'shortDescription', $locale);
            $this->mapTranslationField($translation, $collector, 'metaKeywords', $locale);
            $this->mapTranslationField($translation, $collector, 'metaDescription', $locale);

            $translation->setLocale($locale);
            $product->addTranslation($translation);
        }

        return $product;
    }

    /**
     * @param Translation $translation
     * @param DataCollectorInterface $collector
     * @param string $fieldName
     * @param string $locale
     */
    private function mapTranslationField(Translation $translation, DataCollectorInterface $collector, $fieldName, $locale)
    {
        if ($collector->hasItem($fieldName, $locale)) {
            $method = 'set' . ucfirst(strtolower($fieldName));
            $translation->$method($collector->getItemValue($fieldName, $locale));
        }
    }
}
